package com.jqtx.windows.component.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.extra.cglib.CglibUtil;
import com.jqtx.windows.common.exception.BizException;
import com.jqtx.windows.component.CreditComponent;
import com.jqtx.windows.component.model.CreditModel;
import com.jqtx.windows.infrastructure.enums.ExceptionCodeEnum;
import com.jqtx.windows.repository.entity.WindowsCredit;
import com.jqtx.windows.repository.entity.WindowsCreditExample;
import com.jqtx.windows.repository.mapper.WindowsCreditMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

@Service
public class CreditComponentImpl implements CreditComponent {

    @Autowired
    private WindowsCreditMapper windowsCreditMapper;

    @Override
    public CreditModel getByOrderNo(String orderNo) {
        WindowsCreditExample example = new WindowsCreditExample();
        WindowsCreditExample.Criteria c = example.createCriteria();
        c.andOrderNoEqualTo(orderNo);
        example.setOrderByClause("id desc");
        List<WindowsCredit> list = windowsCreditMapper.selectByExample(example);
        if (CollectionUtil.isNotEmpty(list)) {
            return list.stream().map(e -> CglibUtil.copy(e, CreditModel.class)).findFirst().orElse(null);
        }
        return null;
    }

    @Override
    public void insert(CreditModel model) {
        windowsCreditMapper.insertSelective(CglibUtil.copy(model, WindowsCredit.class));
    }

    @Override
    public void updateByOrderNo(String orderNo, CreditModel model) {
        WindowsCreditExample example = new WindowsCreditExample();
        WindowsCreditExample.Criteria c = example.createCriteria();
        c.andOrderNoEqualTo(orderNo);
        example.setOrderByClause("id desc");
        int i = windowsCreditMapper.updateByExampleSelective(CglibUtil.copy(model, WindowsCredit.class), example);
        if (i != 1) {
            throw new BizException(ExceptionCodeEnum.SYSTEM_SQL_UPDATE_ERROR);
        }
    }

    @Override
    public List<CreditModel> getListModelByCreditThirdStatus(String creditThirdStatus) {
        WindowsCreditExample example = new WindowsCreditExample();
        WindowsCreditExample.Criteria c = example.createCriteria();
        c.andCreditThirdStatusEqualTo(creditThirdStatus);
        example.setOrderByClause("id desc");
        List<WindowsCredit> list = windowsCreditMapper.selectByExample(example);

        return list.stream().map(e -> CglibUtil.copy(e, CreditModel.class)).collect(Collectors.toList());

    }

    @Override
    public List<CreditModel> getListModelByCreditThirdToken(String token) {
        WindowsCreditExample example = new WindowsCreditExample();
        WindowsCreditExample.Criteria c = example.createCriteria();
        c.andCreditThirdTokenEqualTo(token);
        example.setOrderByClause("id desc");
        List<WindowsCredit> list = windowsCreditMapper.selectByExample(example);

        return list.stream().map(e -> CglibUtil.copy(e, CreditModel.class)).collect(Collectors.toList());
    }

    @Override
    public CreditModel getByCertNo(String certNo) {
        WindowsCreditExample example = new WindowsCreditExample();
        WindowsCreditExample.Criteria c = example.createCriteria();
        c.andCertNoEqualTo(certNo);
        example.setOrderByClause("id desc");
        List<WindowsCredit> list = windowsCreditMapper.selectByExample(example);

        return list.stream().map(e -> CglibUtil.copy(e, CreditModel.class)).findFirst().orElse(null);
    }
}
